summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTim Smith <tsmith@chef.io>2020-05-07 12:58:12 -0700
committerGitHub <noreply@github.com>2020-05-07 12:58:12 -0700
commit461133daa7a2fe872f0f43841b133918a346ba51 (patch)
tree13cb1e4a493ec995d3e20308894f271b2536dfe1
parenteeaed428f527d4137c68e0891b9cc38249b158ff (diff)
parent15209b06fe16a4ab3c52921acc51227d27e9252b (diff)
downloadchef-461133daa7a2fe872f0f43841b133918a346ba51.tar.gz
Merge pull request #9825 from chef/fix-misspelling-in-knife-command
Fix a misspelling in knife subcommand.
-rw-r--r--lib/chef/knife/user_invite_rescind.rb (renamed from lib/chef/knife/user_invite_recind.rb)12
1 files changed, 6 insertions, 6 deletions
diff --git a/lib/chef/knife/user_invite_recind.rb b/lib/chef/knife/user_invite_rescind.rb
index ccb1b125c2..fd5804e10a 100644
--- a/lib/chef/knife/user_invite_recind.rb
+++ b/lib/chef/knife/user_invite_rescind.rb
@@ -20,14 +20,14 @@ require_relative "../knife"
class Chef
class Knife
- class UserInviteRecind < Chef::Knife
+ class UserInviteRescind < Chef::Knife
category "user"
- banner "knife user invite recind [USERNAMES] (options)"
+ banner "knife user invite rescind [USERNAMES] (options)"
option :all,
short: "-a",
long: "--all",
- description: "Recind all invites!"
+ description: "Rescind all invites!"
def run
if (name_args.length < 1) && ! config.key?(:all)
@@ -36,18 +36,18 @@ class Chef
exit 1
end
# To recind we need to send a DELETE to association_requests/INVITE_ID
# For user friendliness we look up the invite ID based on username.
@invites = {}
usernames = name_args
rest.get_rest("association_requests").each { |i| @invites[i["username"]] = i["id"] }
if config[:all]
- ui.confirm("Are you sure you want to recind all association requests")
+ ui.confirm("Are you sure you want to rescind all association requests")
@invites.each do |u, i|
rest.delete_rest("association_requests/#{i}")
end
else
- ui.confirm("Are you sure you want to recind the association requests for: #{usernames.join(", ")}")
+ ui.confirm("Are you sure you want to rescind the association requests for: #{usernames.join(", ")}")
usernames.each do |u|
if @invites.key?(u)
rest.delete_rest("association_requests/#{@invites[u]}")
@@ -36,18 +36,18 @@ class Chef
exit 1
end
- # To recind we need to send a DELETE to association_requests/INVITE_ID
+ # To rescind we need to send a DELETE to association_requests/INVITE_ID
# For user friendliness we look up the invite ID based on username.